@@ -7,8 +7,8 @@
 
 
 from selenium.webdriver import Remote
-from weilaizz.templates.http_demo.common.readYaml import  read_yaml
-from weilaizz.templates.http_demo.downloadChromeDriver.downloadBrowser import check_update_chromedriver
+from common.readYaml import  read_yaml
+from downloadChromeDriver.downloadBrowser import check_update_chromedriver
 
 
 def browserInit():
