@@ -5,10 +5,10 @@
 
 
 
-from weilaizz.templates.http_demo.basePage import driver
-from weilaizz.templates.http_demo.basePage.baseUtil import BaseUtil
-from weilaizz.templates.http_demo.common.runTime import _runtime
-from weilaizz.templates.http_demo.common.writeYaml import write_yaml_data
+from basePage import driver
+from basePage.baseUtil import BaseUtil
+from common.runTime import _runtime
+from common.writeYaml import write_yaml_data
 
 """页面层两部分: 1.页面元素存放 2.页面动作执行"""
 class LoginPage(BaseUtil):
