@@ -6,7 +6,7 @@
 
 
 import zmail
-from weilaizz.templates.http_demo.common.readYaml import read_yaml
+from common.readYaml import read_yaml
 
 class SendEmail:
     def __init__(self, subject, content_text, *attachments):
