@@ -6,7 +6,7 @@
 import logging
 import os
 import datetime
-from weilaizz.templates.http_demo.common.basePath import _dir
+from common.basePath import _dir
 
 
 def logFile(fileName, output='all'):
