@@ -7,7 +7,7 @@
 
 import yaml
 import os
-from weilaizz.templates.http_demo.common.basePath import _dir
+from common.basePath import _dir
 from loguru import logger
 
 def read_yaml(key, filename=_dir + 'config/data.yaml'):
