@@ -7,11 +7,11 @@
 
 import os
 import platform
-from weilaizz.templates.http_demo.env import globa
-from weilaizz.templates.http_demo.common.basePath import _dir
-from weilaizz.templates.http_demo.common.clearFile import clearLog as cl, clearFile as cf
+from env import globa
+from basePath import _dir
+from common.clearFile import clearLog as cl, clearFile as cf
 from shutil import copyfile
-from weilaizz.templates.http_demo.env import write_env
+from wenv import write_env
 
 
 def mainSetup():
