@@ -73,9 +73,9 @@ def get_chrome_driver(path=None):
 
 
 if __name__ == "__main__":
-    print(get_chrome_vs())
-    print(get_chromedriver_vs())
-    download_driver('https://registry.npmmirror.com/-/binary/chromedriver/95.0.4638.54/chromedriver_win32.zip')
-    unzip_driver()
-    # check_update_chromedriver()
-    # get_chrome_driver()
+    # print(get_chrome_vs())
+    # print(get_chromedriver_vs())
+    # download_driver('https://registry.npmmirror.com/-/binary/chromedriver/95.0.4638.54/chromedriver_win32.zip')
+    # unzip_driver()
+    # # check_update_chromedriver()
+    get_chrome_driver()
