@@ -5,7 +5,7 @@
 
 import pytest
 
-from weilaizz.templates.http_demo.config.runConfig import mainSetup as ms, mainTearDown as mt
+from config.runConfig import mainSetup as ms, mainTearDown as mt
 
 if __name__ == '__main__':
     ms()        #测试前置
