@@ -7,7 +7,7 @@
 
 import pytest
 import allure
-from weilaizz.templates.http_demo.common.readYaml import load, read_yaml
+from common.readYaml import load, read_yaml
 from loguru import logger
 
 
